@@ -14,6 +14,14 @@ class MetricBase(abc.ABC):
     def __call__(self, preds, targets):
         return self.forward(preds, targets)
 
+    @classmethod
+    def reset(cls):
+        """
+        每个batch后做一些重置工作。
+        注意：这是一处类方法，用于实现在多个指标之间共享数据。
+        """
+        pass
+
     @abc.abstractmethod
     def forward(self, preds, targets):
         return NotImplemented
