@@ -3,8 +3,8 @@ from .metrics import MetricBase
 
 
 class GeneralTaskModule(LightningModule):
-    def __init__(self, model, loss, optimizer, metrics=None, log_step_loss=True, log_epoch_loss=True):
-        super().__init__()
+    def __init__(self, model, loss, optimizer, metrics=None, log_step_loss=True, log_epoch_loss=True, **kwargs):
+        super().__init__(**kwargs)
         self.model = model
         self.loss_fn = loss
         self.opt = optimizer
@@ -59,3 +59,16 @@ class GeneralTaskModule(LightningModule):
                 name = metric.__name__
                 on_step, on_epoch = True, True
             log(f"{state}_{name}", result, prog_bar=True, on_step=on_step, on_epoch=on_epoch)
+
+    def reset_metrics(self):
+        for m in self.metrics:
+            m.reset()
+
+    def on_train_batch_end(self, outputs, batch, batch_idx, dataloader_idx):
+        self.reset_metrics()
+
+    def on_test_batch_end(self, outputs, batch, batch_idx, dataloader_idx):
+        self.reset_metrics()
+
+    def on_validation_batch_end(self, outputs, batch, batch_idx, dataloader_idx):
+        self.reset_metrics()
