@@ -7,6 +7,7 @@ from pytorch_lightning import LightningDataModule
 from pytorch_lightning.loggers import TensorBoardLogger
 from .metrics import MetricBase
 from .tasks import GeneralTaskModule
+from .callbacks import Progress
 
 def default_args(func):
     signature = inspect.signature(func)
@@ -47,6 +48,11 @@ class Trainer(PLTrainer):
         self.init_params = default_args(PLTrainer)
         self.init_params.update(pltrainer_kwargs)     # get default arguments
         self.init_params['num_sanity_val_steps'] = 0  # how many validation steps to execute before running
+        # use Progress callback
+        if self.init_params['callbacks'] is None:
+            self.init_params['callbacks'] = [Progress()]
+        elif not any([isinstance(cbk, Progress) for cbk in self.init_params['callbacks']]):
+            self.init_params['callbacks'].append(Progress())
         # default logger
         if self.init_params['logger'] == True:
             if self.init_params['default_root_dir'] is None:
@@ -65,6 +71,7 @@ class Trainer(PLTrainer):
             super().fit(self.task_module, datamodule=self.datamodule)
         else:
             super().fit(self.task_module, train_dataloaders=train_dl, val_dataloaders=val_dl)
+        return self.progress
 
     def test(self, test_dl=None, ckpt_path='best', pl_module=None, verbose=True):
         if test_dl is not None:
